@@ -52,10 +52,11 @@ def get_script_pattern(request, tag, position):
         'allowed',
         'disallowed'
     )
+    scripts_line = ''
     for block in blocks:
         if (
             not is_disallowed(path, block)
             and is_allowed(path, block)
         ):
-            return mark_safe(block.script)
-    return ''
+            scripts_line += block.script
+    return mark_safe(scripts_line)
